@@ -79,13 +79,9 @@ class Commander(object, metaclass=MetaCommander):
                 subparser.add_argument(*args, **kwds)
             subparser.set_defaults(func=subcmd['func'])
         
-        # Call argcomplete
-        argcomplete.autocomplete(self.parser)
-        
         if len(sys.argv) <= 1:
             options = self.parser.parse_args(self.default_args)
         else:
             options = self.parser.parse_args()
         
         self.options = options
-        options.func(self, options)
